This scraper is a side project from a sentiment analysis project I am working on. 
I decided to package this project as a learning experience since I am new to programming. 
If you have any comments or recommendations on how I could improve or change this, please feel free to get in touch. 
If you have stumbled upon this scraper and would like more features, don't hesitate to contact me.

Documentation for use will be available in the near future.